@@ -11,7 +11,7 @@ use AnyEvent::Socket qw( tcp_server );
 extends 'AnyEvent::FTP::Client::Transfer';
 
 # ABSTRACT: Active transfer class for asynchronous ftp client
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 sub BUILD
 {
@@ -88,11 +88,17 @@ AnyEvent::FTP::Client::Transfer::Active - Active transfer class for asynchronous
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+author: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Ryo Okamoto
+
+Shlomi Fish
 
 =head1 COPYRIGHT AND LICENSE
 
